@@ -22,12 +22,9 @@
  * MA 02111-1307, USA.
  */
 
-#include "buffer.h"
-#include "rsa.h"
-#include "sexp.h"
-#include "yarrow.h"
-
-#include "io.h"
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <ctype.h>
 #include <errno.h>
@@ -38,7 +35,14 @@
 /* For getopt */
 #include <unistd.h>
 
-#define KEYSIZE 500
+#include "buffer.h"
+#include "rsa.h"
+#include "sexp.h"
+#include "yarrow.h"
+
+#include "io.h"
+
+#define KEYSIZE 900
 #define ESIZE 30
 
 static void
@@ -106,7 +110,11 @@ main(int argc, char **argv)
   yarrow256_init(&yarrow, 0, NULL);
 
   /* Read some data to seed the generator */
-  simple_random(&yarrow, random_name);
+  if (!simple_random(&yarrow, random_name))
+    {
+      werror("Initialization of randomness generator failed.\n");
+      return EXIT_FAILURE;
+    }
 
   rsa_public_key_init(&pub);
   rsa_private_key_init(&priv);
